@@ -23,13 +23,20 @@ from pyperf import perf_counter
 
 from synapse.types import ISynapseReactor
 from synapse.util.caches.lrucache import LruCache
+from synapse.util.clock import Clock
 
 
 async def main(reactor: ISynapseReactor, loops: int) -> float:
     """
     Benchmark `loops` number of insertions into LruCache without eviction.
     """
-    cache: LruCache[int, bool] = LruCache(max_size=loops)
+    # Ignore linter error here since we are running outside of the context of a
+    # Synapse `HomeServer`.
+    cache: LruCache[int, bool] = LruCache(
+        max_size=loops,
+        clock=Clock(reactor, server_name="synmark_benchmark"),  # type: ignore[multiple-internal-clocks]
+        server_name="synmark_benchmark",
+    )
 
     start = perf_counter()
 
