@@ -79,15 +79,17 @@ class TypingNotificationsTestCase(unittest.HomeserverTestCase):
     ) -> HomeServer:
         # we mock out the keyring so as to skip the authentication check on the
         # federation API call.
-        mock_keyring = Mock(spec=["verify_json_for_server"])
+        mock_keyring = Mock(spec=["verify_json_for_server", "shutdown"])
         mock_keyring.verify_json_for_server = AsyncMock(return_value=True)
+        mock_keyring.shutdown = Mock()
 
         # we mock out the federation client too
         self.mock_federation_client = AsyncMock(spec=["put_json"])
         self.mock_federation_client.put_json.return_value = (200, "OK")
         self.mock_federation_client.agent = MatrixFederationAgent(
             server_name="OUR_STUB_HOMESERVER_NAME",
-            reactor=reactor,
+            reactor=self.reactor,
+            clock=self.clock,
             tls_client_options_factory=None,
             user_agent=b"SynapseInTrialTest/0.0.0",
             ip_allowlist=None,
@@ -96,7 +98,7 @@ class TypingNotificationsTestCase(unittest.HomeserverTestCase):
         )
 
         # the tests assume that we are starting at unix time 1000
-        reactor.pump((1000,))
+        self.reactor.pump((1000,))
 
         self.mock_hs_notifier = Mock()
         hs = self.setup_test_homeserver(
