@@ -36,7 +36,7 @@ from synapse.rest import admin
 from synapse.rest.client import account, login, profile, room
 from synapse.server import HomeServer
 from synapse.types import JsonDict, Requester, StateMap
-from synapse.util import Clock
+from synapse.util.clock import Clock
 from synapse.util.frozenutils import unfreeze
 
 from tests import unittest
