@@ -17,14 +17,14 @@
 # [This file includes modifications made by New Vector Limited]
 #
 #
+import logging
 import traceback
-from typing import Any, Coroutine, Generator, List, NoReturn, Optional, Tuple, TypeVar
+from typing import Any, Coroutine, List, NoReturn, Optional, Tuple, TypeVar
 
 from parameterized import parameterized_class
 
 from twisted.internet import defer
 from twisted.internet.defer import CancelledError, Deferred, ensureDeferred
-from twisted.internet.task import Clock
 from twisted.python.failure import Failure
 
 from synapse.logging.context import (
@@ -47,6 +47,8 @@ from synapse.util.async_helpers import (
 from tests.server import get_clock
 from tests.unittest import TestCase
 
+logger = logging.getLogger(__name__)
+
 T = TypeVar("T")
 
 
@@ -149,7 +151,7 @@ class ObservableDeferredTest(TestCase):
 
 class TimeoutDeferredTest(TestCase):
     def setUp(self) -> None:
-        self.clock = Clock()
+        self.reactor, self.clock = get_clock()
 
     def test_times_out(self) -> None:
         """Basic test case that checks that the original deferred is cancelled and that
@@ -162,12 +164,16 @@ class TimeoutDeferredTest(TestCase):
             cancelled = True
 
         non_completing_d: Deferred = Deferred(canceller)
-        timing_out_d = timeout_deferred(non_completing_d, 1.0, self.clock)
+        timing_out_d = timeout_deferred(
+            deferred=non_completing_d,
+            timeout=1.0,
+            clock=self.clock,
+        )
 
         self.assertNoResult(timing_out_d)
         self.assertFalse(cancelled, "deferred was cancelled prematurely")
 
-        self.clock.pump((1.0,))
+        self.reactor.pump((1.0,))
 
         self.assertTrue(cancelled, "deferred was not cancelled by timeout")
         self.failureResultOf(timing_out_d, defer.TimeoutError)
@@ -180,57 +186,92 @@ class TimeoutDeferredTest(TestCase):
             raise Exception("can't cancel this deferred")
 
         non_completing_d: Deferred = Deferred(canceller)
-        timing_out_d = timeout_deferred(non_completing_d, 1.0, self.clock)
+        timing_out_d = timeout_deferred(
+            deferred=non_completing_d,
+            timeout=1.0,
+            clock=self.clock,
+        )
 
         self.assertNoResult(timing_out_d)
 
-        self.clock.pump((1.0,))
+        self.reactor.pump((1.0,))
 
         self.failureResultOf(timing_out_d, defer.TimeoutError)
 
-    def test_logcontext_is_preserved_on_cancellation(self) -> None:
-        blocking_was_cancelled = False
+    async def test_logcontext_is_preserved_on_cancellation(self) -> None:
+        # Sanity check that we start in the sentinel context
+        self.assertEqual(current_context(), SENTINEL_CONTEXT)
 
-        @defer.inlineCallbacks
-        def blocking() -> Generator["Deferred[object]", object, None]:
-            nonlocal blocking_was_cancelled
+        incomplete_deferred_was_cancelled = False
 
-            non_completing_d: Deferred = Deferred()
-            with PreserveLoggingContext():
-                try:
-                    yield non_completing_d
-                except CancelledError:
-                    blocking_was_cancelled = True
-                    raise
+        def mark_was_cancelled(res: Failure) -> None:
+            """
+            A passthrough errback which sets `incomplete_deferred_was_cancelled`.
 
-        with LoggingContext("one") as context_one:
-            # the errbacks should be run in the test logcontext
-            def errback(res: Failure, deferred_name: str) -> Failure:
-                self.assertIs(
-                    current_context(),
-                    context_one,
-                    "errback %s run in unexpected logcontext %s"
-                    % (deferred_name, current_context()),
+            This means we re-raise any exception and allows further errbacks (in
+            `timeout_deferred(...)`) to do their thing. Just trying to be a transparent
+            proxy of any exception while doing our internal test book-keeping.
+            """
+            nonlocal incomplete_deferred_was_cancelled
+            if res.check(CancelledError):
+                incomplete_deferred_was_cancelled = True
+            else:
+                logger.error(
+                    "Expected incomplete_d to fail with `CancelledError` because our "
+                    "`timeout_deferred(...)` utility canceled it but saw %s",
+                    res,
                 )
-                return res
 
-            original_deferred = blocking()
-            original_deferred.addErrback(errback, "orig")
-            timing_out_d = timeout_deferred(original_deferred, 1.0, self.clock)
-            self.assertNoResult(timing_out_d)
-            self.assertIs(current_context(), SENTINEL_CONTEXT)
-            timing_out_d.addErrback(errback, "timingout")
+            # Re-raise the exception so that any further errbacks can do their thing as
+            # normal
+            res.raiseException()
 
-            self.clock.pump((1.0,))
+        # Create a deferred which we will never complete
+        incomplete_d: Deferred = Deferred()
+        incomplete_d.addErrback(mark_was_cancelled)
 
-            self.assertTrue(
-                blocking_was_cancelled, "non-completing deferred was not cancelled"
+        with LoggingContext(name="one", server_name="test_server") as context_one:
+            timing_out_d = timeout_deferred(
+                deferred=incomplete_d,
+                timeout=1.0,
+                clock=self.clock,
             )
-            self.failureResultOf(timing_out_d, defer.TimeoutError)
+            self.assertNoResult(timing_out_d)
+            # We should still be in the logcontext we started in
             self.assertIs(current_context(), context_one)
 
+            # Pump the reactor until we trigger the timeout
+            #
+            # We're manually pumping the reactor (and causing any pending callbacks to
+            # be called) so we need to be in the sentinel logcontext to avoid leaking
+            # our current logcontext into the reactor (which would then get picked up
+            # and associated with the next thing the reactor does). `with
+            # PreserveLoggingContext()` will reset the logcontext to the sentinel while
+            # we're pumping the reactor in the block and return us back to our current
+            # logcontext after the block.
+            with PreserveLoggingContext():
+                self.reactor.pump(
+                    # We only need to pump `1.0` (seconds) as we set
+                    # `timeout_deferred(timeout=1.0)` above
+                    (1.0,)
+                )
 
-class _TestException(Exception):
+            # We expect the incomplete deferred to have been cancelled because of the
+            # timeout by this point
+            self.assertTrue(
+                incomplete_deferred_was_cancelled,
+                "incomplete deferred was not cancelled",
+            )
+            # We should see the `TimeoutError` (instead of a `CancelledError`)
+            self.failureResultOf(timing_out_d, defer.TimeoutError)
+            # We're still in the same logcontext
+            self.assertIs(current_context(), context_one)
+
+        # Back to the sentinel context
+        self.assertEqual(current_context(), SENTINEL_CONTEXT)
+
+
+class _TestException(Exception):  #
     pass
 
 
@@ -502,7 +543,7 @@ class DelayCancellationTests(TestCase):
             await make_deferred_yieldable(blocking_d)
 
         async def outer() -> None:
-            with LoggingContext("c") as c:
+            with LoggingContext(name="c", server_name="test_server") as c:
                 try:
                     await delay_cancellation(inner())
                     self.fail("`CancelledError` was not raised")
@@ -526,8 +567,8 @@ class AwakenableSleeperTests(TestCase):
     "Tests AwakenableSleeper"
 
     def test_sleep(self) -> None:
-        reactor, _ = get_clock()
-        sleeper = AwakenableSleeper(reactor)
+        reactor, clock = get_clock()
+        sleeper = AwakenableSleeper(clock)
 
         d = defer.ensureDeferred(sleeper.sleep("name", 1000))
 
@@ -541,8 +582,8 @@ class AwakenableSleeperTests(TestCase):
         self.assertTrue(d.called)
 
     def test_explicit_wake(self) -> None:
-        reactor, _ = get_clock()
-        sleeper = AwakenableSleeper(reactor)
+        reactor, clock = get_clock()
+        sleeper = AwakenableSleeper(clock)
 
         d = defer.ensureDeferred(sleeper.sleep("name", 1000))
 
@@ -558,8 +599,8 @@ class AwakenableSleeperTests(TestCase):
         reactor.advance(0.6)
 
     def test_multiple_sleepers_timeout(self) -> None:
-        reactor, _ = get_clock()
-        sleeper = AwakenableSleeper(reactor)
+        reactor, clock = get_clock()
+        sleeper = AwakenableSleeper(clock)
 
         d1 = defer.ensureDeferred(sleeper.sleep("name", 1000))
 
@@ -578,8 +619,8 @@ class AwakenableSleeperTests(TestCase):
         self.assertTrue(d2.called)
 
     def test_multiple_sleepers_wake(self) -> None:
-        reactor, _ = get_clock()
-        sleeper = AwakenableSleeper(reactor)
+        reactor, clock = get_clock()
+        sleeper = AwakenableSleeper(clock)
 
         d1 = defer.ensureDeferred(sleeper.sleep("name", 1000))
 
@@ -617,7 +658,7 @@ class GatherCoroutineTests(TestCase):
     def test_single(self) -> None:
         "Test passing in a single coroutine works"
 
-        with LoggingContext("test_ctx") as text_ctx:
+        with LoggingContext(name="test_ctx", server_name="test_server") as text_ctx:
             deferred: "defer.Deferred[None]"
             coroutine, deferred = self.make_coroutine()
 
@@ -643,7 +684,7 @@ class GatherCoroutineTests(TestCase):
     def test_multiple_resolve(self) -> None:
         "Test passing in multiple coroutine that all resolve works"
 
-        with LoggingContext("test_ctx") as test_ctx:
+        with LoggingContext(name="test_ctx", server_name="test_server") as test_ctx:
             deferred1: "defer.Deferred[int]"
             coroutine1, deferred1 = self.make_coroutine()
             deferred2: "defer.Deferred[str]"
@@ -676,7 +717,7 @@ class GatherCoroutineTests(TestCase):
     def test_multiple_fail(self) -> None:
         "Test passing in multiple coroutine where one fails does the right thing"
 
-        with LoggingContext("test_ctx") as test_ctx:
+        with LoggingContext(name="test_ctx", server_name="test_server") as test_ctx:
             deferred1: "defer.Deferred[int]"
             coroutine1, deferred1 = self.make_coroutine()
             deferred2: "defer.Deferred[str]"
